activeRequestId property
String?
get
activeRequestId
The request id currently waiting for a terminal response.
Implementation
String? get activeRequestId => _activeRequestId;
The request id currently waiting for a terminal response.
String? get activeRequestId => _activeRequestId;