onRequestIgnored method
Called when a callback is ignored because it does not match the active request.
Implementation
void onRequestIgnored(String method, dynamic arguments) {}
Called when a callback is ignored because it does not match the active request.
void onRequestIgnored(String method, dynamic arguments) {}