requestArguments method
Creates a new request id and wraps the platform arguments with it.
Native implementations should echo requestIdKey back in callback payloads so delayed or duplicated callbacks can be ignored by this receiver.
Implementation
Map<String, dynamic> requestArguments(dynamic arguments) {
_activeRequestId = Utils.fastUUID();
onRequest(_activeRequestId, arguments);
return {
requestIdKey: _activeRequestId,
requestArgumentsKey: arguments,
};
}