requestArgumentsKey constant
String
const requestArgumentsKey
The payload key used to store the original request arguments.
Implementation
static const String requestArgumentsKey = 'arguments';
The payload key used to store the original request arguments.
static const String requestArgumentsKey = 'arguments';