responseDataKey constant
String
const responseDataKey
The payload key used to store response data in native callbacks.
Implementation
static const String responseDataKey = 'responseData';
The payload key used to store response data in native callbacks.
static const String responseDataKey = 'responseData';