PlatformNotificationManager class abstract
An abstract class for the platform notification manager.
This class is used to create an abstract class for the platform notification manager.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invokeListMethod<
T> (String method, [dynamic arguments, PlatformNotification? notification]) → Future< List< T> ?> - A method for invoking a native platform method that returns a list.
-
invokeMethod<
T> (String method, [dynamic arguments, PlatformNotification? notification]) → Future< T?> - A method for invoking a native platform method.
-
n2fCallDispatcher(
MethodCall call) → dynamic - A method for dispatching the notification to the platform.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerChannel(
String channelName, {Future handler(MethodCall call)?}) → void - A method for registering the native method channel.
-
subscribe(
List< PlatformNotification> notifications) → void - A method for subscribing to the notification.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited