invokeListMethod<T> abstract method
Future<List<T> ?>
invokeListMethod<T>(
- String method, [
- dynamic arguments,
- PlatformNotification? notification
A method for invoking a native platform method that returns a list.
Ping-pong notifications automatically wrap arguments with a request id.
Implementation
Future<List<T>?> invokeListMethod<T>(
String method, [
dynamic arguments,
PlatformNotification? notification,
]);